OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "New note" : "Nova nota",
    "Delete note" : "Apagar nota",
    "_%n word_::_%n words_" : ["%n palavra","%n palavras"]
},
"nplurals=2; plural=(n != 1);");
